==> klogshow_1.0.3.orig.tar.gz: klogshow-1.0.3/src/klogshow.h <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   pinon.pierre@gmail.com                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KLOGSHOW_H
#define KLOGSHOW_H

/*====== TODO ========

- Bug de scroll end
- Presence dans la barre des taches
- Bug : L'application semble se fermer sous windows sur l'instruction close()

======== TODO ======*/

//Parametres de l'application
#define NAME_APP				"KlogShow"
#define VERSION_APP				"1.0.3"
#define ICON_APP				":/images/klogshow.png"

#define ABOUT_TEXT				tr("Author : PINON Pierre\nVersion : ") + tr(VERSION_APP) + tr("\nE-Mail : pinon.pierre@gmail.com\n\nReport bugs or anythings else in my e-mail !\n\nThanks : http://www.qtfr.org\n - lud42fr\n - pasnox\n - IrmatDen\n - nouknouk")
#define MAX_FILES				1000
#define INTERVAL_BLINK			500

//Programmes et Arguments
#define KDE_SU					"kdesu"
#define GNOME_SU				"gnomesu"
#define PARAM_START_BY_APP		"--start_by_app"
#define PARAM_CONF_FILENAME		"--conf_filename="

//Fichier de config
#ifdef UNIX
	#define FILE_CONF_PATH		".klogshow/klogshow.conf"
#endif
#ifdef WIN32
	#define FILE_CONF_PATH		"klogshow/klogshow.conf"
#endif
#define CONF_PATH				QDir::toNativeSeparators (QDir::homePath() + "/" + FILE_CONF_PATH)
#define LOG_FILE( num )			"logfiles/file" + QString::number ( num )
#define LOG_CONFIG_BASE( num )	"logfile" + QString::number ( num )
#define LOG_CONFIG( num, param )	LOG_CONFIG_BASE( num ) + "/" + param
#define NONE_VALUE				"{None}"

//Proprietes par defaut de l'application
#define DEFAULT_OPACITY			60
#define DEFAULT_SELECT			false
#define DEFAULT_DECOR			false
#define DEFAULT_TITLE			true
#define DEFAULT_SCROLL			false
#define DEFAULT_ROOT			false
#define DEFAULT_APPSU			KDE_SU
#define DEFAULT_EVENTWIN			true
#define DEFAULT_EVENTTIME		5

//Proprietes par defaut des fenetres de log
#define DEFAULT_ACTIVATE			false
#define GEO_DEFAULT_X			320
#define GEO_DEFAULT_Y			240
#define GEO_DEFAULT_WIDTH		640
#define GEO_DEFAULT_HEIGHT		480

#endif

==> klogshow_1.0.4.orig.tar.gz: klogshow-1.0.4/src/klogshow.h <==
/***************************************************************************
 *   Copyright (C) 2007 by xes                                             *
 *   xes@xesnet.fr                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KLOGSHOW_H
#define KLOGSHOW_H

//Parametres de l'application
#define NAME_APP				"KlogShow"
#define VERSION_APP				"1.0.4"
#define ICON_APP				":/images/klogshow.png"

#define ABOUT_TEXT				tr("Author : PINON Pierre\nVersion : ") + tr(VERSION_APP) + tr("\nE-Mail : xes@xesnet.fr\nWeb site : http://www.xesnet.fr\n\nReport bugs or anythings else in my e-mail !\n\nThanks : http://www.qtfr.org\n - lud42fr\n - pasnox\n - IrmatDen\n - nouknouk")
#define MAX_FILES				1000
#define INTERVAL_BLINK			500

//Programmes et Arguments
#define KDE_SU					"kdesu"
#define GNOME_SU				"gnomesu"
#define PARAM_START_BY_APP		"--start_by_app"
#define PARAM_CONF_FILENAME		"--conf_filename="

//Fichier de config
#ifdef __linux__
	#define FILE_CONF_PATH		".klogshow/klogshow.conf"
#endif
#ifdef _WIN32
	#define FILE_CONF_PATH		"klogshow/klogshow.conf"
#endif
#define CONF_PATH				QDir::toNativeSeparators (QDir::homePath() + "/" + FILE_CONF_PATH)
#define LOG_FILE( num )			"logfiles/file" + QString::number ( num )
#define LOG_CONFIG_BASE( num )	"logfile" + QString::number ( num )
#define LOG_CONFIG( num, param )	LOG_CONFIG_BASE( num ) + "/" + param
#define NONE_VALUE				"{None}"

//Proprietes par defaut de l'application
#define DEFAULT_OPACITY			60
#define DEFAULT_SELECT			false
#define DEFAULT_DECOR			false
#define DEFAULT_TITLE			true
#define DEFAULT_SCROLL			false
#define DEFAULT_ROOT			false
#define DEFAULT_APPSU			KDE_SU
#define DEFAULT_EVENTWIN			true
#define DEFAULT_EVENTTIME		5

//Proprietes par defaut des fenetres de log
#define DEFAULT_ACTIVATE			false
#define GEO_DEFAULT_X			320
#define GEO_DEFAULT_Y			240
#define GEO_DEFAULT_WIDTH		640
#define GEO_DEFAULT_HEIGHT		480
#define DEFAULT_TEXT_COLOR		QColor ( 255, 255, 255 )
#define DEFAULT_BACK_COLOR_TOP	QColor ( 0, 0, 0 )
#define DEFAULT_BACK_COLOR_BOTTOM	QColor ( 50, 50, 50 )

//Images
#define IMG_TITLE1				":/images/title1.png"
#define IMG_TITLE1_BIS			":/images/title1b.png"
#define IMG_TITLE2				":/images/title2.png"
#define IMG_TITLE2_BIS			":/images/title2b.png"

#endif
